@@ -1,7 +1,7 @@
 import collections
 from itertools import chain
 from jinja2 import Environment, FileSystemLoader
-from rdflib import SDO, SKOS, OWL, URIRef, RDF, PROF, Literal, XSD, Namespace, FOAF, Graph
+from rdflib import SDO, SKOS, OWL, URIRef, RDF, PROF, Literal, XSD, Graph, Namespace, FOAF, Graph
 
 from pylode.common import TEMPLATES_DIR
 
@@ -522,6 +522,7 @@ class BaseProfile:
         org_url = None
         org_email = None
         for p, o in self.G.predicate_objects(subject=agent_node):
+            print(p, o)
             if p in [FOAF.homepage, SDO.identifier]:
                 url = str(o)
             elif p in [FOAF.name, SDO.name]:
@@ -530,17 +531,22 @@ class BaseProfile:
                 email = str(o).split("/")[-1].split("#")[-1]  # remove base URI leaving only email address
             elif p in [SDO.memberOf, SDO.affiliation]:
                 for p2, o2 in self.G.predicate_objects(subject=o):
-                    if p2 in [FOAF.homepage, SDO.identifier, SDO.url]:  # TODO: split homepage from IDs, cater for rdfs:seeAlso
+                    if p2 in [FOAF.homepage, SDO.identifier, SDO.url]:  # TODO: split homepage form IDs, cater for rdfs:seeAlso
                         org_url = str(o2)
                     elif p2 in [FOAF.name, SDO.name]:
                         org_name = str(o2)
                     elif p in [FOAF.mbox, SDO.email]:
                         org_email = str(o2).split("/")[-1].split("#")[-1]  # remove base URI leaving only email address
 
-            # use the URI of the Agent for its URL if no FOAF.homepage or SDO.identifier has been set
-            if url is None and type(agent_node) == URIRef:
-                url = str(agent_node)
+        # use the URI of the Agent for its URL if no FOAF.homepage or SDO.identifier has been set
+        if url is None and type(agent_node) == URIRef:
+            url = str(agent_node)
 
+        if name is None:
+            if type(agent_node) == Literal:
+                name = agent_node
+            if type(agent_node) == URIRef:
+                name = agent_node.split("/")[-1].split("#")[-1]
         agent = self._make_agent_link(name, url=url, email=email)
 
         if org_name is not None:
